@@ -1,9 +1,7 @@
 package Data::DPath::Step;
-BEGIN {
-  $Data::DPath::Step::AUTHORITY = 'cpan:SCHWIGON';
-}
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Abstraction for a single Step through a Path
-$Data::DPath::Step::VERSION = '0.55';
+$Data::DPath::Step::VERSION = '0.58';
 use strict;
 use warnings;
 
@@ -56,7 +54,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2019 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
